@@ -30,7 +30,7 @@
 #include "object_heap.h"
 #include "v4l2_base_type.h"
 
-#define MAX_STREAMS 100
+#define MAX_STREAMS 200
 #define MAX_GOP_SIZE 8
 #define MAX_INTRA_PIC_RATE 0x7fffffff
 #define NO_RESPONSE_SEQID 0xFFFFFFFE
@@ -127,7 +127,7 @@ typedef enum {
   V4L2_DAEMON_VIDIOC_STREAMON = 0,  // for streamon and start
   V4L2_DAEMON_VIDIOC_BUF_RDY,
   V4L2_DAEMON_VIDIOC_CMD_STOP,   // this is for flush.
-  V4L2_DAEMON_VIDIOC_STREAMOFF,   //enc destroy
+  V4L2_DAEMON_VIDIOC_DESTROY_ENC,   //enc destroy
   V4L2_DAEMON_VIDIOC_ENC_RESET,   //enc reset, as in spec
   //above are enc cmds
 
@@ -154,6 +154,7 @@ typedef enum {
   V4L2_DAEMON_VIDIOC_CROPCHANGE,
   V4L2_DAEMON_VIDIOC_WARNONOPTION,
   V4L2_DAEMON_VIDIOC_STREAMOFF_CAPTURE_DONE,
+  V4L2_DAEMON_VIDIOC_STREAMOFF_OUTPUT_DONE,
   V4L2_DAEMON_VIDIOC_TOTAL_AMOUNT,
 } v4l2_daemon_cmd_id;
 
