@@ -79,7 +79,8 @@ char cmd_name[V4L2_DAEMON_VIDIOC_TOTAL_AMOUNT][50] = {
     "V4L2_DAEMON_VIDIOC_STREAMON",
     "V4L2_DAEMON_VIDIOC_BUF_RDY",
     "V4L2_DAEMON_VIDIOC_CMD_STOP",
-    "V4L2_DAEMON_VIDIOC_STREAMOFF",
+    "V4L2_DAEMON_VIDIOC_DESTROY_ENC",
+    "V4L2_DAEMON_VIDIOC_ENC_RESET",
     "V4L2_DAEMON_VIDIOC_FAKE",
     "V4L2_DAEMON_VIDIOC_S_EXT_CTRLS",
     "V4L2_DAEMON_VIDIOC_RESET_BITRATE",
