@@ -75,8 +75,22 @@ static i32 rv_get_stream_mode(struct DWLLinearMem *in_mem) {
 static u32 rv_dec_parse_sliceinfo(struct DWLLinearMem *in_mem,
                                   RvDecSliceInfo *slice_info) {
   u32 slice_info_num = 0, frame_length = 0, hdr_bytes = 0;
-  u8 *buff = (u8 *)in_mem->virtual_address;
   u32 i;
+  u8 *buff = NULL;
+
+  if (RV_MODE == rv_get_stream_mode(in_mem)) {
+        u8 *frame_hdr_p = (u8 *)in_mem->virtual_address;
+        u32 frame_hdr_length = (frame_hdr_p[0] << 24) | (frame_hdr_p[1] << 16) | (frame_hdr_p[2] << 8) | (frame_hdr_p[3] << 0);
+        if (frame_hdr_length >= in_mem->logical_size) {
+            HANTRO_LOG(HANTRO_LEVEL_DEBUG, "repeatedly transfer codec data\n");
+            return 0;
+        }
+        in_mem->logical_size -= frame_hdr_length;
+        in_mem->virtual_address = (u32 *)((u8 *)in_mem->virtual_address + frame_hdr_length);
+        in_mem->bus_address = (addr_t)((u8 *)in_mem->bus_address + frame_hdr_length);
+  }
+
+  buff = (u8 *)in_mem->virtual_address;
 
   frame_length =
       (buff[0] << 24) | (buff[1] << 16) | (buff[2] << 8) | (buff[3] << 0);
@@ -426,10 +440,8 @@ v4l2_inst_dec_event rv_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
     if (rv_priv->total_slice_info_size == 0) {
       rv_priv->slice_info_num =
           rv_dec_parse_sliceinfo(in_mem, rv_priv->slice_info);
-      if (rv_priv->slice_info_num == 0) {
-        re_dec_event = DEC_FATAL_ERROR_EVENT;
-        goto end;
-      }
+      if (rv_priv->slice_info_num == 0) 
+        goto update_input;
 
       rv_priv->total_slice_info_size = NEXT_MULTIPLE(
           16 + rv_priv->slice_info_num * 8 + 4, RV_SLICE_DATA_ALIGN);
