@@ -622,7 +622,6 @@ v4l2_inst_dec_event vc1g_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
   v4l2_inst_dec_event re_dec_event = DEC_EMPTY_EVENT;
   i32 ret = 0;
   u32 skip_non_reference = 0;
-  u32 raw_frame_data = 0;
   VC1DecInput dec_input = {0};
   VC1DecOutput dec_output = {0};
   VC1DecInfo dec_info = {0};
@@ -635,13 +634,12 @@ v4l2_inst_dec_event vc1g_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
   dec_input.skip_non_reference = skip_non_reference;
   dec_input.stream_size = in_mem->logical_size;
   dec_input.pic_id = h->dec_in_pic_id; /*curr_pic_id*/
-  if (h->dec_in_new_packet) {
-    if (VC1_IS_NAL_HDR(dec_input.stream, 0) ||
-        VC1_IS_NAL_HDR(dec_input.stream, 1))
-      raw_frame_data = 0;
-    else
-      raw_frame_data = 1;
-    VC1DecSetFrameDataMode(dec_inst, raw_frame_data);
+  if (VC1_IS_NAL_HDR(dec_input.stream, 0) ||
+      VC1_IS_NAL_HDR(dec_input.stream, 1)) {
+    VC1DecSetFrameDataMode(dec_inst, 0);
+  } else {
+    if (h->dec_in_new_packet)
+      VC1DecSetFrameDataMode(dec_inst, 1);
   }
   HANTRO_LOG(HANTRO_LEVEL_INFO, "input: %p %lx stream len: %d\n",
              dec_input.stream, dec_input.stream_bus_address,
