@@ -1265,7 +1265,8 @@ int encoder_find_next_pic_h1(v4l2_enc_inst *h, BUFFER **p_buffer,
  */
 void reset_enc_h1(v4l2_enc_inst *h)
 {
-    return;
+  h->input_frame_cnt = 0;
+  h->output_frame_cnt = 0;
 }
 
 /**
@@ -1314,8 +1315,9 @@ int encoder_close_h1(v4l2_enc_inst *h) {
                    ret);
       }
     }
+    h->inst = NULL;
   }
-
+  if(h->cbr_bitrate_change) return ret;
   if (h->bufferlist_input) bufferlist_flush(h->bufferlist_input);
   if (h->bufferlist_output) bufferlist_flush(h->bufferlist_output);
   if (h->bufferlist_reorder) bufferlist_flush(h->bufferlist_reorder);
