@@ -2410,6 +2410,8 @@ void reset_enc_h2(v4l2_enc_inst *h) {
 
   //when get reset command, reset picture_cnt
   encIn->picture_cnt = 0;
+  h->input_frame_cnt = 0;
+  h->output_frame_cnt = 0;
 }
 
 /**
@@ -2443,8 +2445,9 @@ int encoder_close_h2(v4l2_enc_inst *h) {
     if (ret != VCENC_OK) {
       HANTRO_LOG(HANTRO_LEVEL_INFO, "VCEncRelease failed, ret=%d\n", ret);
     }
+    h->inst = NULL;
   }
-
+  if(h->cbr_bitrate_change) return ret;
   if (h->bufferlist_input) bufferlist_flush(h->bufferlist_input);
   if (h->bufferlist_output) bufferlist_flush(h->bufferlist_output);
   if (h->bufferlist_reorder) bufferlist_flush(h->bufferlist_reorder);
